#! /bin/bash

# User must be member of "src" group

mseroot=./mseide-msegui
#mseurl=https://github.com/mse-org/mseide-msegui
#mseurl=https://codeberg.org/fredvs/mseide-msegui
mseurl=https://codeberg.org/mse-org/mseide-msegui

git clone $mseurl $mseroot

if [ "$?" != "0" ]
then
pushd $mseroot
G_RESULT=`LANG=en_US.UTF8 git pull | grep "Already up to date"`
popd
    if [ "$G_RESULT" != "" ]
    then
    echo $G_RESULT
    exit
    fi
fi

# git checkout adb75e0eb2

echo "Update Ok :)"